==> istio-model-v1beta1-6.1.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/LocalityLoadBalancerSettingFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface LocalityLoadBalancerSettingFluent<A extends LocalityLoadBalancerSettingFluent<A>> extends Fluent<A>{
  public A addToDistribute(Integer index,LocalityLoadBalancerSettingDistribute item);
  public A setToDistribute(Integer index,LocalityLoadBalancerSettingDistribute item);
  public A addToDistribute(io.fabric8.istio.api.networking.v1beta1.LocalityLoadBalancerSettingDistribute... items);
  public A addAllToDistribute(Collection<LocalityLoadBalancerSettingDistribute> items);
  public A removeFromDistribute(io.fabric8.istio.api.networking.v1beta1.LocalityLoadBalancerSettingDistribute... items);
  public A removeAllFromDistribute(Collection<LocalityLoadBalancerSettingDistribute> items);
  public A removeMatchingFromDistribute(Predicate<LocalityLoadBalancerSettingDistributeBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildDistribute instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<LocalityLoadBalancerSettingDistribute> getDistribute();
  public List<LocalityLoadBalancerSettingDistribute> buildDistribute();
  public LocalityLoadBalancerSettingDistribute buildDistribute(Integer index);
  public LocalityLoadBalancerSettingDistribute buildFirstDistribute();
  public LocalityLoadBalancerSettingDistribute buildLastDistribute();
  public LocalityLoadBalancerSettingDistribute buildMatchingDistribute(Predicate<LocalityLoadBalancerSettingDistributeBuilder> predicate);
  public Boolean hasMatchingDistribute(Predicate<LocalityLoadBalancerSettingDistributeBuilder> predicate);
  public A withDistribute(List<LocalityLoadBalancerSettingDistribute> distribute);
  public A withDistribute(io.fabric8.istio.api.networking.v1beta1.LocalityLoadBalancerSettingDistribute... distribute);
  public Boolean hasDistribute();
  public LocalityLoadBalancerSettingFluent.DistributeNested<A> addNewDistribute();
  public LocalityLoadBalancerSettingFluent.DistributeNested<A> addNewDistributeLike(LocalityLoadBalancerSettingDistribute item);
  public LocalityLoadBalancerSettingFluent.DistributeNested<A> setNewDistributeLike(Integer index,LocalityLoadBalancerSettingDistribute item);
  public LocalityLoadBalancerSettingFluent.DistributeNested<A> editDistribute(Integer index);
  public LocalityLoadBalancerSettingFluent.DistributeNested<A> editFirstDistribute();
  public LocalityLoadBalancerSettingFluent.DistributeNested<A> editLastDistribute();
  public LocalityLoadBalancerSettingFluent.DistributeNested<A> editMatchingDistribute(Predicate<LocalityLoadBalancerSettingDistributeBuilder> predicate);
  public Boolean getEnabled();
  public A withEnabled(Boolean enabled);
  public Boolean hasEnabled();
  public A addToFailover(Integer index,LocalityLoadBalancerSettingFailover item);
  public A setToFailover(Integer index,LocalityLoadBalancerSettingFailover item);
  public A addToFailover(io.fabric8.istio.api.networking.v1beta1.LocalityLoadBalancerSettingFailover... items);
  public A addAllToFailover(Collection<LocalityLoadBalancerSettingFailover> items);
  public A removeFromFailover(io.fabric8.istio.api.networking.v1beta1.LocalityLoadBalancerSettingFailover... items);
  public A removeAllFromFailover(Collection<LocalityLoadBalancerSettingFailover> items);
  public A removeMatchingFromFailover(Predicate<LocalityLoadBalancerSettingFailoverBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildFailover instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<LocalityLoadBalancerSettingFailover> getFailover();
  public List<LocalityLoadBalancerSettingFailover> buildFailover();
  public LocalityLoadBalancerSettingFailover buildFailover(Integer index);
  public LocalityLoadBalancerSettingFailover buildFirstFailover();
  public LocalityLoadBalancerSettingFailover buildLastFailover();
  public LocalityLoadBalancerSettingFailover buildMatchingFailover(Predicate<LocalityLoadBalancerSettingFailoverBuilder> predicate);
  public Boolean hasMatchingFailover(Predicate<LocalityLoadBalancerSettingFailoverBuilder> predicate);
  public A withFailover(List<LocalityLoadBalancerSettingFailover> failover);
  public A withFailover(io.fabric8.istio.api.networking.v1beta1.LocalityLoadBalancerSettingFailover... failover);
  public Boolean hasFailover();
  public A addNewFailover(String from,String to);
  public LocalityLoadBalancerSettingFluent.FailoverNested<A> addNewFailover();
  public LocalityLoadBalancerSettingFluent.FailoverNested<A> addNewFailoverLike(LocalityLoadBalancerSettingFailover item);
  public LocalityLoadBalancerSettingFluent.FailoverNested<A> setNewFailoverLike(Integer index,LocalityLoadBalancerSettingFailover item);
  public LocalityLoadBalancerSettingFluent.FailoverNested<A> editFailover(Integer index);
  public LocalityLoadBalancerSettingFluent.FailoverNested<A> editFirstFailover();
  public LocalityLoadBalancerSettingFluent.FailoverNested<A> editLastFailover();
  public LocalityLoadBalancerSettingFluent.FailoverNested<A> editMatchingFailover(Predicate<LocalityLoadBalancerSettingFailoverBuilder> predicate);
  public A addToFailoverPriority(Integer index,String item);
  public A setToFailoverPriority(Integer index,String item);
  public A addToFailoverPriority(java.lang.String... items);
  public A addAllToFailoverPriority(Collection<String> items);
  public A removeFromFailoverPriority(java.lang.String... items);
  public A removeAllFromFailoverPriority(Collection<String> items);
  public List<String> getFailoverPriority();
  public String getFailoverPriority(Integer index);
  public String getFirstFailoverPriority();
  public String getLastFailoverPriority();
  public String getMatchingFailoverPriority(Predicate<String> predicate);
  public Boolean hasMatchingFailoverPriority(Predicate<String> predicate);
  public A withFailoverPriority(List<String> failoverPriority);
  public A withFailoverPriority(java.lang.String... failoverPriority);
  public Boolean hasFailoverPriority();
  public A withEnabled();
  public interface DistributeNested<N> extends Nested<N>,LocalityLoadBalancerSettingDistributeFluent<LocalityLoadBalancerSettingFluent.DistributeNested<N>>{
    public N and();
    public N endDistribute();
    
  }
  public interface FailoverNested<N> extends Nested<N>,LocalityLoadBalancerSettingFailoverFluent<LocalityLoadBalancerSettingFluent.FailoverNested<N>>{
    public N and();
    public N endFailover();
    
  }
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/LocalityLoadBalancerSettingFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface LocalityLoadBalancerSettingFluent<A extends LocalityLoadBalancerSettingFluent<A>> extends Fluent<A>{
  public A addToDistribute(int index,LocalityLoadBalancerSettingDistribute item);
  public A setToDistribute(int index,LocalityLoadBalancerSettingDistribute item);
  public A addToDistribute(io.fabric8.istio.api.networking.v1beta1.LocalityLoadBalancerSettingDistribute... items);
  public A addAllToDistribute(Collection<LocalityLoadBalancerSettingDistribute> items);
  public A removeFromDistribute(io.fabric8.istio.api.networking.v1beta1.LocalityLoadBalancerSettingDistribute... items);
  public A removeAllFromDistribute(Collection<LocalityLoadBalancerSettingDistribute> items);
  public A removeMatchingFromDistribute(Predicate<LocalityLoadBalancerSettingDistributeBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildDistribute instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<LocalityLoadBalancerSettingDistribute> getDistribute();
  public List<LocalityLoadBalancerSettingDistribute> buildDistribute();
  public LocalityLoadBalancerSettingDistribute buildDistribute(int index);
  public LocalityLoadBalancerSettingDistribute buildFirstDistribute();
  public LocalityLoadBalancerSettingDistribute buildLastDistribute();
  public LocalityLoadBalancerSettingDistribute buildMatchingDistribute(Predicate<LocalityLoadBalancerSettingDistributeBuilder> predicate);
  public Boolean hasMatchingDistribute(Predicate<LocalityLoadBalancerSettingDistributeBuilder> predicate);
  public A withDistribute(List<LocalityLoadBalancerSettingDistribute> distribute);
  public A withDistribute(io.fabric8.istio.api.networking.v1beta1.LocalityLoadBalancerSettingDistribute... distribute);
  public Boolean hasDistribute();
  public LocalityLoadBalancerSettingFluent.DistributeNested<A> addNewDistribute();
  public LocalityLoadBalancerSettingFluent.DistributeNested<A> addNewDistributeLike(LocalityLoadBalancerSettingDistribute item);
  public LocalityLoadBalancerSettingFluent.DistributeNested<A> setNewDistributeLike(int index,LocalityLoadBalancerSettingDistribute item);
  public LocalityLoadBalancerSettingFluent.DistributeNested<A> editDistribute(int index);
  public LocalityLoadBalancerSettingFluent.DistributeNested<A> editFirstDistribute();
  public LocalityLoadBalancerSettingFluent.DistributeNested<A> editLastDistribute();
  public LocalityLoadBalancerSettingFluent.DistributeNested<A> editMatchingDistribute(Predicate<LocalityLoadBalancerSettingDistributeBuilder> predicate);
  public Boolean getEnabled();
  public A withEnabled(Boolean enabled);
  public Boolean hasEnabled();
  public A addToFailover(int index,LocalityLoadBalancerSettingFailover item);
  public A setToFailover(int index,LocalityLoadBalancerSettingFailover item);
  public A addToFailover(io.fabric8.istio.api.networking.v1beta1.LocalityLoadBalancerSettingFailover... items);
  public A addAllToFailover(Collection<LocalityLoadBalancerSettingFailover> items);
  public A removeFromFailover(io.fabric8.istio.api.networking.v1beta1.LocalityLoadBalancerSettingFailover... items);
  public A removeAllFromFailover(Collection<LocalityLoadBalancerSettingFailover> items);
  public A removeMatchingFromFailover(Predicate<LocalityLoadBalancerSettingFailoverBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildFailover instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<LocalityLoadBalancerSettingFailover> getFailover();
  public List<LocalityLoadBalancerSettingFailover> buildFailover();
  public LocalityLoadBalancerSettingFailover buildFailover(int index);
  public LocalityLoadBalancerSettingFailover buildFirstFailover();
  public LocalityLoadBalancerSettingFailover buildLastFailover();
  public LocalityLoadBalancerSettingFailover buildMatchingFailover(Predicate<LocalityLoadBalancerSettingFailoverBuilder> predicate);
  public Boolean hasMatchingFailover(Predicate<LocalityLoadBalancerSettingFailoverBuilder> predicate);
  public A withFailover(List<LocalityLoadBalancerSettingFailover> failover);
  public A withFailover(io.fabric8.istio.api.networking.v1beta1.LocalityLoadBalancerSettingFailover... failover);
  public Boolean hasFailover();
  public A addNewFailover(String from,String to);
  public LocalityLoadBalancerSettingFluent.FailoverNested<A> addNewFailover();
  public LocalityLoadBalancerSettingFluent.FailoverNested<A> addNewFailoverLike(LocalityLoadBalancerSettingFailover item);
  public LocalityLoadBalancerSettingFluent.FailoverNested<A> setNewFailoverLike(int index,LocalityLoadBalancerSettingFailover item);
  public LocalityLoadBalancerSettingFluent.FailoverNested<A> editFailover(int index);
  public LocalityLoadBalancerSettingFluent.FailoverNested<A> editFirstFailover();
  public LocalityLoadBalancerSettingFluent.FailoverNested<A> editLastFailover();
  public LocalityLoadBalancerSettingFluent.FailoverNested<A> editMatchingFailover(Predicate<LocalityLoadBalancerSettingFailoverBuilder> predicate);
  public A addToFailoverPriority(int index,String item);
  public A setToFailoverPriority(int index,String item);
  public A addToFailoverPriority(java.lang.String... items);
  public A addAllToFailoverPriority(Collection<String> items);
  public A removeFromFailoverPriority(java.lang.String... items);
  public A removeAllFromFailoverPriority(Collection<String> items);
  public List<String> getFailoverPriority();
  public String getFailoverPriority(int index);
  public String getFirstFailoverPriority();
  public String getLastFailoverPriority();
  public String getMatchingFailoverPriority(Predicate<String> predicate);
  public Boolean hasMatchingFailoverPriority(Predicate<String> predicate);
  public A withFailoverPriority(List<String> failoverPriority);
  public A withFailoverPriority(java.lang.String... failoverPriority);
  public Boolean hasFailoverPriority();
  public A withEnabled();
  public interface DistributeNested<N> extends Nested<N>,LocalityLoadBalancerSettingDistributeFluent<LocalityLoadBalancerSettingFluent.DistributeNested<N>>{
    public N and();
    public N endDistribute();
    
  }
  public interface FailoverNested<N> extends Nested<N>,LocalityLoadBalancerSettingFailoverFluent<LocalityLoadBalancerSettingFluent.FailoverNested<N>>{
    public N and();
    public N endFailover();
    
  }
  
}
